@@ -53,6 +53,7 @@
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_PARAM_H 1
+#define HAVE_SYS_RANDOM_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
 #define HAVE_SYS_SOCKET_H 1
@@ -63,6 +64,9 @@
 #define HAVE_TIME_H 1
 #define HAVE_UCONTEXT_H 1
 #define HAVE_UTIME_H 1
+#if defined(__i386__)
+#define HAVE_X86INTRIN_H 1
+#endif
 #define HAVE_TYPEOF 1
 #define restrict __restrict__
 #define HAVE_LONG_LONG 1
@@ -130,10 +134,11 @@
 #define OFFT2NUM(v) LL2NUM(v)
 #define NUM2OFFT(v) NUM2LL(v)
 #define PRI_OFFT_PREFIX PRI_LL_PREFIX
-#define rb_clockid_t int
-#define SIGNEDNESS_OF_CLOCKID_T -1
-#define CLOCKID2NUM(v) INT2NUM(v)
-#define NUM2CLOCKID(v) NUM2INT(v)
+#define HAVE_CLOCKID_T 1
+#define rb_clockid_t clockid_t
+#define SIGNEDNESS_OF_CLOCKID_T +1
+#define CLOCKID2NUM(v) UINT2NUM(v)
+#define NUM2CLOCKID(v) NUM2UINT(v)
 #define PRI_CLOCKID_PREFIX PRI_INT_PREFIX
 #define HAVE_VA_ARGS_MACRO 1
 #define HAVE__ALIGNOF 1
@@ -167,6 +172,7 @@
 #define HAVE_DECL_GETENV 1
 #define SIZEOF_SIZE_T 4
 #define SIZEOF_PTRDIFF_T 4
+#define SIZEOF_DEV_T 4
 #define PRI_SIZE_PREFIX "z"
 #define PRI_PTRDIFF_PREFIX "t"
 #define HAVE_STRUCT_STAT_ST_BLKSIZE 1
@@ -175,6 +181,8 @@
 #define SIZEOF_STRUCT_STAT_ST_SIZE SIZEOF_OFF_T
 #define SIZEOF_STRUCT_STAT_ST_BLOCKS SIZEOF_OFF_T
 #define SIZEOF_STRUCT_STAT_ST_INO SIZEOF_LONG_LONG
+#define SIZEOF_STRUCT_STAT_ST_DEV SIZEOF_DEV_T
+#define SIZEOF_STRUCT_STAT_ST_RDEV SIZEOF_DEV_T
 #define HAVE_STRUCT_STAT_ST_ATIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_MTIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_CTIMESPEC 1
@@ -209,10 +217,11 @@
 #define GETGROUPS_T gid_t
 #define HAVE_ALLOCA_H 1
 #define HAVE_ALLOCA 1
+#define HAVE_DUP 1
+#define HAVE_DUP2 1
 #define HAVE_ACOSH 1
 #define HAVE_CBRT 1
 #define HAVE_CRYPT 1
-#define HAVE_DUP2 1
 #define HAVE_ERF 1
 #define HAVE_FFS 1
 #define HAVE_FLOCK 1
@@ -227,33 +236,36 @@
 #define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_TGAMMA 1
-#define HAVE_FINITE 1
-#define HAVE_ISINF 1
-#define HAVE_ISNAN 1
+#define HAVE_ISFINITE 1
 #define SPT_TYPE SPT_REUSEARGV
 #define HAVE_SIGNBIT 1
 #define HAVE_FORK 1
 #define vfork fork
 #define HAVE_WORKING_FORK 1
 #define HAVE__LONGJMP 1
+#define HAVE_ARC4RANDOM_BUF 1
 #define HAVE_ATAN2L 1
 #define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
+#define HAVE_CLOCK_GETTIME 1
 #define HAVE_COSH 1
+#define HAVE_DIRFD 1
 #define HAVE_DLOPEN 1
 #define HAVE_DLADDR 1
-#define HAVE_DUP 1
 #define HAVE_ENDGRENT 1
 #define HAVE_FCOPYFILE 1
 #define HAVE_FCHMOD 1
 #define HAVE_FCHOWN 1
 #define HAVE_FCNTL 1
+#define HAVE_FDOPENDIR 1
 #define HAVE_FGETATTRLIST 1
 #define HAVE_FMOD 1
+#define HAVE_FSTATAT 1
 #define HAVE_FSYNC 1
 #define HAVE_FTRUNCATE 1
 #define HAVE_GETATTRLIST 1
 #define HAVE_GETCWD 1
+#define HAVE_GETENTROPY 1
 #define HAVE_GETGRNAM 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_GETGROUPS 1
@@ -286,9 +298,12 @@
 #define HAVE_MALLOC_SIZE 1
 #define HAVE_MBLEN 1
 #define HAVE_WRITEV 1
+#define HAVE_MEMMEM 1
 #define HAVE_MKFIFO 1
 #define HAVE_MKNOD 1
 #define HAVE_MKTIME 1
+#define HAVE_MMAP 1
+#define HAVE_OPENAT 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PREAD 1
@@ -327,6 +342,7 @@
 #define HAVE_TIMES 1
 #define HAVE_TRUNCATE 1
 #define HAVE_UNSETENV 1
+#define HAVE_UTIMENSAT 1
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
@@ -350,8 +366,10 @@
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_BUILTIN___BUILTIN_TRAP 1
+#define HAVE_BUILTIN___BUILTIN_EXPECT 1
 #define HAVE_BSD_QSORT_R 1
 #define ATAN2_INF_C99 1
+#define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -362,7 +380,7 @@
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
-#define COROUTINE_H "coroutine/x86/Context.h"
+#define COROUTINE_H "coroutine/pthread/Context.h"
 #define _REENTRANT 1
 #define _THREAD_SAFE 1
 #define HAVE_LIBPTHREAD 1
@@ -372,10 +390,14 @@
 #define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
 #define HAVE_PTHREAD_GET_STACKADDR_NP 1
 #define HAVE_PTHREAD_GET_STACKSIZE_NP 1
-#define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SETNAME_NP 1
+#define HAVE_PTHREAD_SIGMASK 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_setname_np(name)
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t mc = (uc)->uc_mcontext
+#define HAVE_SYS_USER_H 1
+#define HAVE_CONST_PAGE_SIZE 1
+#define IOCTL_REQ_TYPE unsigned long
+#define NUM2IOCTLREQ(num) NUM2ULONG(num)
 #define HAVE_MACH_O_LOADER_H 1
 #define HAVE_LIBPROC_H 1
 #define HAVE_EXECINFO_H 1
@@ -392,5 +414,7 @@
 #define RUBY_JMP_BUF sigjmp_buf
 #define USE_MJIT 1
 #define HAVE_PTHREAD_H 1
+#define THREAD_IMPL_H "thread_pthread.h"
+#define THREAD_IMPL_SRC "thread_pthread.c"
 #define RUBY_PLATFORM "i386-darwin10.0"
 #endif /* INCLUDE_RUBY_CONFIG_H */
